# Copyright (C) 2010 Richard Lincoln
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from dynamics import Element

# <<< imports
# @generated
# >>> imports

ns_prefix = "cim"

ns_uri = "http://iec.ch/TC57/2009/CIM-schema-cim14#Package_VoltageCompensator"

class VoltageCompensator(Element):
    """ A voltage compensator adjusts the terminal voltage feedback to the excitation system by adding a quantity that is proportional to the terminal current of the generator. It is linked to a specific generator by the Bus number and Unit IDA voltage compensator adjusts the terminal voltage feedback to the excitation system by adding a quantity that is proportional to the terminal current of the generator. It is linked to a specific generator by the Bus number and Unit ID
    """
    # <<< voltage_compensator
    # @generated
    def __init__(self, rcomp=0.0, xcomp=0.0, **kw_args):
        """ Initialises a new 'VoltageCompensator' instance.
        """
        # Compensating (compounding) resistanceCompensating (compounding) resistance 
        self.rcomp = rcomp

        # Compensating (compounding) reactanceCompensating (compounding) reactance 
        self.xcomp = xcomp



        super(VoltageCompensator, self).__init__(**kw_args)
    # >>> voltage_compensator


    def __str__(self):
        """ Returns a string representation of the VoltageCompensator.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< voltage_compensator.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the VoltageCompensator.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "VoltageCompensator", self.uri)
        if format:
            indent += ' ' * depth

        s += '%s<%s:VoltageCompensator.rcomp>%s</%s:VoltageCompensator.rcomp>' % \
            (indent, ns_prefix, self.rcomp, ns_prefix)
        s += '%s<%s:VoltageCompensator.xcomp>%s</%s:VoltageCompensator.xcomp>' % \
            (indent, ns_prefix, self.xcomp, ns_prefix)
        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "VoltageCompensator")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> voltage_compensator.serialize


class VcompIEEE(VoltageCompensator):
    """ IEEE Voltage Compensation ModelIEEE Voltage Compensation Model
    """
    pass
    # <<< vcomp_ieee
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'VcompIEEE' instance.
        """


        super(VcompIEEE, self).__init__(**kw_args)
    # >>> vcomp_ieee


    def __str__(self):
        """ Returns a string representation of the VcompIEEE.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< vcomp_ieee.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the VcompIEEE.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "VcompIEEE", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        s += '%s<%s:VoltageCompensator.rcomp>%s</%s:VoltageCompensator.rcomp>' % \
            (indent, ns_prefix, self.rcomp, ns_prefix)
        s += '%s<%s:VoltageCompensator.xcomp>%s</%s:VoltageCompensator.xcomp>' % \
            (indent, ns_prefix, self.xcomp, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "VcompIEEE")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> vcomp_ieee.serialize


class VcompCross(VoltageCompensator):
    """ Voltage Compensation Model for Cross-Compound Generating UnitVoltage Compensation Model for Cross-Compound Generating Unit
    """
    # <<< vcomp_cross
    # @generated
    def __init__(self, xcomp2=0.0, rcomp2=0.0, **kw_args):
        """ Initialises a new 'VcompCross' instance.
        """
        # Cross-Compensating (compounding) reactanceCross-Compensating (compounding) reactance 
        self.xcomp2 = xcomp2

        # Cross-Compensating (compounding) resistanceCross-Compensating (compounding) resistance 
        self.rcomp2 = rcomp2



        super(VcompCross, self).__init__(**kw_args)
    # >>> vcomp_cross


    def __str__(self):
        """ Returns a string representation of the VcompCross.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< vcomp_cross.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the VcompCross.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "VcompCross", self.uri)
        if format:
            indent += ' ' * depth

        s += '%s<%s:VcompCross.xcomp2>%s</%s:VcompCross.xcomp2>' % \
            (indent, ns_prefix, self.xcomp2, ns_prefix)
        s += '%s<%s:VcompCross.rcomp2>%s</%s:VcompCross.rcomp2>' % \
            (indent, ns_prefix, self.rcomp2, ns_prefix)
        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        s += '%s<%s:VoltageCompensator.rcomp>%s</%s:VoltageCompensator.rcomp>' % \
            (indent, ns_prefix, self.rcomp, ns_prefix)
        s += '%s<%s:VoltageCompensator.xcomp>%s</%s:VoltageCompensator.xcomp>' % \
            (indent, ns_prefix, self.xcomp, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "VcompCross")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> vcomp_cross.serialize


# <<< voltage_compensator
# @generated
# >>> voltage_compensator



# Copyright (C) 2010 Richard Lincoln
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from dynamics import Element

# <<< imports
# @generated
# >>> imports

ns_prefix = "cim"

ns_uri = "http://iec.ch/TC57/2009/CIM-schema-cim14#Package_PowerSystemStabilizers"

class PowerSystemStabilizer(Element):
    """ A PSS provides an input (Vs) to the excitation system model to improve damping of system oscillations.  A variety of input signals may be used depending on the particular design.A PSS provides an input (Vs) to the excitation system model to improve damping of system oscillations.  A variety of input signals may be used depending on the particular design.
    """
    pass
    # <<< power_system_stabilizer
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PowerSystemStabilizer' instance.
        """


        super(PowerSystemStabilizer, self).__init__(**kw_args)
    # >>> power_system_stabilizer


    def __str__(self):
        """ Returns a string representation of the PowerSystemStabilizer.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< power_system_stabilizer.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PowerSystemStabilizer.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PowerSystemStabilizer", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PowerSystemStabilizer")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> power_system_stabilizer.serialize


class PssIEEE4B(PowerSystemStabilizer):
    """ PSS type IEEE PSS4BPSS type IEEE PSS4B
    """
    pass
    # <<< pss_ieee4_b
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssIEEE4B' instance.
        """


        super(PssIEEE4B, self).__init__(**kw_args)
    # >>> pss_ieee4_b


    def __str__(self):
        """ Returns a string representation of the PssIEEE4B.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_ieee4_b.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssIEEE4B.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssIEEE4B", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssIEEE4B")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_ieee4_b.serialize


class PssIEEE2B(PowerSystemStabilizer):
    """ IEEE (2005) PSS2B Model  This stabilizer model is designed to represent a variety of dual-input stabilizers, which normally use combinations of power and speed or frequency to derive the stabilizing signal.IEEE (2005) PSS2B Model  This stabilizer model is designed to represent a variety of dual-input stabilizers, which normally use combinations of power and speed or frequency to derive the stabilizing signal.
    """
    # <<< pss_ieee2_b
    # @generated
    def __init__(self, t10=0.0, a=0.0, ks1=0.0, ks3=0.0, t11=0.0, ks2=0.0, vstmin=0.0, vsi1max=0.0, vsi2max=0.0, tb=0.0, t2=0.0, ta=0.0, t1=0.0, t4=0.0, n=False, t3=0.0, m=False, t6=0.0, t8=0.0, vsi1min=0.0, t7=0.0, t9=0.0, ks4=0.0, tw2=0.0, tw1=0.0, tw4=0.0, vsi2min=0.0, tw3=0.0, vstmax=0.0, **kw_args):
        """ Initialises a new 'PssIEEE2B' instance.
        """
        # Lead/lag time constantLead/lag time constant 
        self.t10 = t10

        # Numerator constantNumerator constant 
        self.a = a

        # Stabilizer gainStabilizer gain 
        self.ks1 = ks1

        # Gain on signal #2 input before ramp-tracking filterGain on signal #2 input before ramp-tracking filter 
        self.ks3 = ks3

        # Lead/lag time constantLead/lag time constant 
        self.t11 = t11

        # Gain on signal #2Gain on signal #2 
        self.ks2 = ks2

        # Stabilizer output min limitStabilizer output min limit 
        self.vstmin = vstmin

        # Input signal #1 max limitInput signal #1 max limit 
        self.vsi1max = vsi1max

        # Input signal #2 max limitInput signal #2 max limit 
        self.vsi2max = vsi2max

        # Lag time constantLag time constant 
        self.tb = tb

        # Lead/lag time constantLead/lag time constant 
        self.t2 = t2

        # Lead constantLead constant 
        self.ta = ta

        # Lead/lag time constantLead/lag time constant 
        self.t1 = t1

        # Lead/lag time constantLead/lag time constant 
        self.t4 = t4

        # Order of ramp tracking filterOrder of ramp tracking filter 
        self.n = n

        # Lead/lag time constantLead/lag time constant 
        self.t3 = t3

        # Denominator order of ramp tracking filterDenominator order of ramp tracking filter 
        self.m = m

        # Time constant on signal #1Time constant on signal #1 
        self.t6 = t6

        # Lead of ramp tracking filterLead of ramp tracking filter 
        self.t8 = t8

        # Input signal #1 min limitInput signal #1 min limit 
        self.vsi1min = vsi1min

        # Time constant on signal #2Time constant on signal #2 
        self.t7 = t7

        # Lag of ramp tracking filterLag of ramp tracking filter 
        self.t9 = t9

        # Gain on signal #2 input after ramp-tracking filterGain on signal #2 input after ramp-tracking filter 
        self.ks4 = ks4

        # Second washout on signal #1Second washout on signal #1 
        self.tw2 = tw2

        # First washout on signal #1First washout on signal #1 
        self.tw1 = tw1

        # Second washout on signal #2Second washout on signal #2 
        self.tw4 = tw4

        # Input signal #2 min limitInput signal #2 min limit 
        self.vsi2min = vsi2min

        # First washout on signal #2First washout on signal #2 
        self.tw3 = tw3

        # Stabilizer output max limitStabilizer output max limit 
        self.vstmax = vstmax



        super(PssIEEE2B, self).__init__(**kw_args)
    # >>> pss_ieee2_b


    def __str__(self):
        """ Returns a string representation of the PssIEEE2B.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_ieee2_b.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssIEEE2B.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssIEEE2B", self.uri)
        if format:
            indent += ' ' * depth

        s += '%s<%s:PssIEEE2B.t10>%s</%s:PssIEEE2B.t10>' % \
            (indent, ns_prefix, self.t10, ns_prefix)
        s += '%s<%s:PssIEEE2B.a>%s</%s:PssIEEE2B.a>' % \
            (indent, ns_prefix, self.a, ns_prefix)
        s += '%s<%s:PssIEEE2B.ks1>%s</%s:PssIEEE2B.ks1>' % \
            (indent, ns_prefix, self.ks1, ns_prefix)
        s += '%s<%s:PssIEEE2B.ks3>%s</%s:PssIEEE2B.ks3>' % \
            (indent, ns_prefix, self.ks3, ns_prefix)
        s += '%s<%s:PssIEEE2B.t11>%s</%s:PssIEEE2B.t11>' % \
            (indent, ns_prefix, self.t11, ns_prefix)
        s += '%s<%s:PssIEEE2B.ks2>%s</%s:PssIEEE2B.ks2>' % \
            (indent, ns_prefix, self.ks2, ns_prefix)
        s += '%s<%s:PssIEEE2B.vstmin>%s</%s:PssIEEE2B.vstmin>' % \
            (indent, ns_prefix, self.vstmin, ns_prefix)
        s += '%s<%s:PssIEEE2B.vsi1max>%s</%s:PssIEEE2B.vsi1max>' % \
            (indent, ns_prefix, self.vsi1max, ns_prefix)
        s += '%s<%s:PssIEEE2B.vsi2max>%s</%s:PssIEEE2B.vsi2max>' % \
            (indent, ns_prefix, self.vsi2max, ns_prefix)
        s += '%s<%s:PssIEEE2B.tb>%s</%s:PssIEEE2B.tb>' % \
            (indent, ns_prefix, self.tb, ns_prefix)
        s += '%s<%s:PssIEEE2B.t2>%s</%s:PssIEEE2B.t2>' % \
            (indent, ns_prefix, self.t2, ns_prefix)
        s += '%s<%s:PssIEEE2B.ta>%s</%s:PssIEEE2B.ta>' % \
            (indent, ns_prefix, self.ta, ns_prefix)
        s += '%s<%s:PssIEEE2B.t1>%s</%s:PssIEEE2B.t1>' % \
            (indent, ns_prefix, self.t1, ns_prefix)
        s += '%s<%s:PssIEEE2B.t4>%s</%s:PssIEEE2B.t4>' % \
            (indent, ns_prefix, self.t4, ns_prefix)
        s += '%s<%s:PssIEEE2B.n>%s</%s:PssIEEE2B.n>' % \
            (indent, ns_prefix, self.n, ns_prefix)
        s += '%s<%s:PssIEEE2B.t3>%s</%s:PssIEEE2B.t3>' % \
            (indent, ns_prefix, self.t3, ns_prefix)
        s += '%s<%s:PssIEEE2B.m>%s</%s:PssIEEE2B.m>' % \
            (indent, ns_prefix, self.m, ns_prefix)
        s += '%s<%s:PssIEEE2B.t6>%s</%s:PssIEEE2B.t6>' % \
            (indent, ns_prefix, self.t6, ns_prefix)
        s += '%s<%s:PssIEEE2B.t8>%s</%s:PssIEEE2B.t8>' % \
            (indent, ns_prefix, self.t8, ns_prefix)
        s += '%s<%s:PssIEEE2B.vsi1min>%s</%s:PssIEEE2B.vsi1min>' % \
            (indent, ns_prefix, self.vsi1min, ns_prefix)
        s += '%s<%s:PssIEEE2B.t7>%s</%s:PssIEEE2B.t7>' % \
            (indent, ns_prefix, self.t7, ns_prefix)
        s += '%s<%s:PssIEEE2B.t9>%s</%s:PssIEEE2B.t9>' % \
            (indent, ns_prefix, self.t9, ns_prefix)
        s += '%s<%s:PssIEEE2B.ks4>%s</%s:PssIEEE2B.ks4>' % \
            (indent, ns_prefix, self.ks4, ns_prefix)
        s += '%s<%s:PssIEEE2B.tw2>%s</%s:PssIEEE2B.tw2>' % \
            (indent, ns_prefix, self.tw2, ns_prefix)
        s += '%s<%s:PssIEEE2B.tw1>%s</%s:PssIEEE2B.tw1>' % \
            (indent, ns_prefix, self.tw1, ns_prefix)
        s += '%s<%s:PssIEEE2B.tw4>%s</%s:PssIEEE2B.tw4>' % \
            (indent, ns_prefix, self.tw4, ns_prefix)
        s += '%s<%s:PssIEEE2B.vsi2min>%s</%s:PssIEEE2B.vsi2min>' % \
            (indent, ns_prefix, self.vsi2min, ns_prefix)
        s += '%s<%s:PssIEEE2B.tw3>%s</%s:PssIEEE2B.tw3>' % \
            (indent, ns_prefix, self.tw3, ns_prefix)
        s += '%s<%s:PssIEEE2B.vstmax>%s</%s:PssIEEE2B.vstmax>' % \
            (indent, ns_prefix, self.vstmax, ns_prefix)
        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssIEEE2B")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_ieee2_b.serialize


class PssSB4(PowerSystemStabilizer):
    """ Power sensitive stabilizer modelPower sensitive stabilizer model
    """
    pass
    # <<< pss_sb4
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssSB4' instance.
        """


        super(PssSB4, self).__init__(**kw_args)
    # >>> pss_sb4


    def __str__(self):
        """ Returns a string representation of the PssSB4.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_sb4.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssSB4.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssSB4", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssSB4")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_sb4.serialize


class PssSB(PowerSystemStabilizer):
    """ Dual input PSS, pss2a and transient stabilizerDual input PSS, pss2a and transient stabilizer
    """
    pass
    # <<< pss_sb
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssSB' instance.
        """


        super(PssSB, self).__init__(**kw_args)
    # >>> pss_sb


    def __str__(self):
        """ Returns a string representation of the PssSB.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_sb.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssSB.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssSB", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssSB")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_sb.serialize


class PssSK(PowerSystemStabilizer):
    """ PSS Slovakian type &ndash; three inputsPSS Slovakian type &ndash; three inputs
    """
    pass
    # <<< pss_sk
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssSK' instance.
        """


        super(PssSK, self).__init__(**kw_args)
    # >>> pss_sk


    def __str__(self):
        """ Returns a string representation of the PssSK.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_sk.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssSK.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssSK", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssSK")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_sk.serialize


class PssPTIST3(PowerSystemStabilizer):
    """ PTI microprocessor-based stabilizer model type 3PTI microprocessor-based stabilizer model type 3
    """
    pass
    # <<< pss_ptist3
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssPTIST3' instance.
        """


        super(PssPTIST3, self).__init__(**kw_args)
    # >>> pss_ptist3


    def __str__(self):
        """ Returns a string representation of the PssPTIST3.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_ptist3.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssPTIST3.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssPTIST3", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssPTIST3")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_ptist3.serialize


class PssIEEE1A(PowerSystemStabilizer):
    """ PSS type IEEE PSS1APSS type IEEE PSS1A
    """
    pass
    # <<< pss_ieee1_a
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssIEEE1A' instance.
        """


        super(PssIEEE1A, self).__init__(**kw_args)
    # >>> pss_ieee1_a


    def __str__(self):
        """ Returns a string representation of the PssIEEE1A.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_ieee1_a.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssIEEE1A.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssIEEE1A", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssIEEE1A")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_ieee1_a.serialize


class PssIEEE3B(PowerSystemStabilizer):
    """ PSS type IEEE PSS3BPSS type IEEE PSS3B
    """
    pass
    # <<< pss_ieee3_b
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssIEEE3B' instance.
        """


        super(PssIEEE3B, self).__init__(**kw_args)
    # >>> pss_ieee3_b


    def __str__(self):
        """ Returns a string representation of the PssIEEE3B.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_ieee3_b.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssIEEE3B.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssIEEE3B", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssIEEE3B")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_ieee3_b.serialize


class PssWSCC(PowerSystemStabilizer):
    """ Dual input PSSDual input PSS
    """
    pass
    # <<< pss_wscc
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssWSCC' instance.
        """


        super(PssWSCC, self).__init__(**kw_args)
    # >>> pss_wscc


    def __str__(self):
        """ Returns a string representation of the PssWSCC.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_wscc.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssWSCC.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssWSCC", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssWSCC")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_wscc.serialize


class PssPTIST1(PowerSystemStabilizer):
    """ PTI microprocessor-based stabilizer model type 1PTI microprocessor-based stabilizer model type 1
    """
    pass
    # <<< pss_ptist1
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssPTIST1' instance.
        """


        super(PssPTIST1, self).__init__(**kw_args)
    # >>> pss_ptist1


    def __str__(self):
        """ Returns a string representation of the PssPTIST1.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_ptist1.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssPTIST1.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssPTIST1", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssPTIST1")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_ptist1.serialize


class PssSH(PowerSystemStabilizer):
    """ Siemens H infinity PSSSiemens H infinity PSS
    """
    pass
    # <<< pss_sh
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'PssSH' instance.
        """


        super(PssSH, self).__init__(**kw_args)
    # >>> pss_sh


    def __str__(self):
        """ Returns a string representation of the PssSH.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< pss_sh.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PssSH.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PssSH", self.uri)
        if format:
            indent += ' ' * depth

        if self.model is not None:
            s += '%s<%s:Element.model rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.model.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PssSH")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> pss_sh.serialize


# <<< power_system_stabilizers
# @generated
# >>> power_system_stabilizers



# Copyright (C) 2010 Richard Lincoln
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

""" The package is used to define detailed customer models.
"""

from cim.iec61968.common import Agreement
from cim.iec61968.common import Document
from cim.iec61970.core import Curve

# <<< imports
# @generated
# >>> imports

ns_prefix = "cim.infcustomers"

ns_uri = "http://iec.ch/TC57/2009/CIM-schema-cim14#InfCustomers"

class ExternalCustomerAgreement(Agreement):
    """ A type of customer agreement involving an external agency. For example, a customer may form a contracts with an Energy Service Supplier if Direct Access is permitted.
    """
    pass
    # <<< external_customer_agreement
    # @generated
    def __init__(self, **kw_args):
        """ Initialises a new 'ExternalCustomerAgreement' instance.
        """


        super(ExternalCustomerAgreement, self).__init__(**kw_args)
    # >>> external_customer_agreement


    def __str__(self):
        """ Returns a string representation of the ExternalCustomerAgreement.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< external_customer_agreement.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the ExternalCustomerAgreement.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "ExternalCustomerAgreement", self.uri)
        if format:
            indent += ' ' * depth

        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)
        if self.validity_interval is not None:
            s += '%s<%s:Agreement.validity_interval rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.validity_interval.uri)
        s += '%s<%s:Agreement.sign_date>%s</%s:Agreement.sign_date>' % \
            (indent, ns_prefix, self.sign_date, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "ExternalCustomerAgreement")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> external_customer_agreement.serialize


class StandardIndustryCode(Document):
    """ The Standard Industrial Classification (SIC) are the codes that identify the type of products/service an industry is involved in, and used for statutory reporting purposes. For example, in the USA these codes are located by the federal government, and then published in a book entitled 'The Standard Industrial Classification Manual'. The codes are arranged in a hierarchical structure. Note that Residential Service Agreements are not classified according to the SIC codes.
    """
    # <<< standard_industry_code
    # @generated
    def __init__(self, code='', customer_agreements=None, **kw_args):
        """ Initialises a new 'StandardIndustryCode' instance.
        """
        # Standard alphanumeric code assigned to a particular product/service within an industry. 
        self.code = code


        self._customer_agreements = []
        if customer_agreements is not None:
            self.customer_agreements = customer_agreements
        else:
            self.customer_agreements = []


        super(StandardIndustryCode, self).__init__(**kw_args)
    # >>> standard_industry_code

    # <<< customer_agreements
    # @generated
    def get_customer_agreements(self):
        """ 
        """
        return self._customer_agreements

    def set_customer_agreements(self, value):
        for x in self._customer_agreements:
            x._standard_industry_code = None
        for y in value:
            y._standard_industry_code = self
        self._customer_agreements = value

    customer_agreements = property(get_customer_agreements, set_customer_agreements)

    def add_customer_agreements(self, *customer_agreements):
        for obj in customer_agreements:
            obj._standard_industry_code = self
            self._customer_agreements.append(obj)

    def remove_customer_agreements(self, *customer_agreements):
        for obj in customer_agreements:
            obj._standard_industry_code = None
            self._customer_agreements.remove(obj)
    # >>> customer_agreements


    def __str__(self):
        """ Returns a string representation of the StandardIndustryCode.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< standard_industry_code.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the StandardIndustryCode.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "StandardIndustryCode", self.uri)
        if format:
            indent += ' ' * depth

        for obj in self.customer_agreements:
            s += '%s<%s:StandardIndustryCode.customer_agreements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:StandardIndustryCode.code>%s</%s:StandardIndustryCode.code>' % \
            (indent, ns_prefix, self.code, ns_prefix)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "StandardIndustryCode")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> standard_industry_code.serialize


class CustomerBillingInfo(Document):
    """ The creation of the monthly customer billing statements is the method employed to notify Customers of charges, adjustments and credits applied to their account for Services and Products. The actuall billing occurs through an ErpInvoice. The CustomerBillingInfo includes information from the payment, collection, meter reading, installed meter, service, site, customer, customer account, customer agreement, services and pricing subject areas. Each component price shows up as a separate line item on the ErpInvoice. The Customer Billing Statement may include collection and account messages, marketing/civic event messages and bill inserts. One Customer Billing Statement is produced for all Agreements under a CustomerAccount per billing cycle date defined in 'CustomerAccount.billingCycle'. The history of CustomerBillingInfo, Invoices and Payments is to be maintained in associated ActivityRecords.
    """
    # <<< customer_billing_info
    # @generated
    def __init__(self, kind='separate_ess_udc', pymt_plan_type='', billing_date='', pymt_plan_amt=0.0, out_balance=0.0, last_payment_amt=0.0, last_payment_date='', due_date='', erp_invoice_line_items=None, customer_account=None, **kw_args):
        """ Initialises a new 'CustomerBillingInfo' instance.
        """
        # Kind of bill customer receives. Values are: "separate_ess_udc", "other", "consolidated_ess", "consolidated_udc"
        self.kind = 'separate_ess_udc'

        # Type of payment plan. 
        self.pymt_plan_type = pymt_plan_type

        # Business date designated for the billing run which produced this CustomerBillingInfo. 
        self.billing_date = billing_date

        # Monthly amortized amount due during each billing cycle for the CustomerAccount balance for which the Payment Plan is set-up. 
        self.pymt_plan_amt = pymt_plan_amt

        # Outstanding balance on the CustomerAccount as of the statement date. 
        self.out_balance = out_balance

        # Amount of the last payment received from the customer. It is retained in the Customer Billing system, although the details of each payment are tracked in the ERP system. 
        self.last_payment_amt = last_payment_amt

        # Date of the last payment received from the customer. It is retained in the Customer Billing system, although the details of each payment are tracked in the ERP system. 
        self.last_payment_date = last_payment_date

        # Calculated date upon which a customer billing amount is due, used in the invoicing process to determine when a Customer's Payment is delinquent. It takes into consideration the regulatory criteria and the Customer's requested due date. In the absence of a Customer requested due date, the due date is typically calculated from the regulated number of days and the 'billingDate'. 
        self.due_date = due_date


        self._erp_invoice_line_items = []
        if erp_invoice_line_items is not None:
            self.erp_invoice_line_items = erp_invoice_line_items
        else:
            self.erp_invoice_line_items = []

        self._customer_account = None
        self.customer_account = customer_account


        super(CustomerBillingInfo, self).__init__(**kw_args)
    # >>> customer_billing_info

    # <<< erp_invoice_line_items
    # @generated
    def get_erp_invoice_line_items(self):
        """ 
        """
        return self._erp_invoice_line_items

    def set_erp_invoice_line_items(self, value):
        for p in self._erp_invoice_line_items:
            filtered = [q for q in p.customer_billing_infos if q != self]
            self._erp_invoice_line_items._customer_billing_infos = filtered
        for r in value:
            if self not in r._customer_billing_infos:
                r._customer_billing_infos.append(self)
        self._erp_invoice_line_items = value

    erp_invoice_line_items = property(get_erp_invoice_line_items, set_erp_invoice_line_items)

    def add_erp_invoice_line_items(self, *erp_invoice_line_items):
        for obj in erp_invoice_line_items:
            if self not in obj._customer_billing_infos:
                obj._customer_billing_infos.append(self)
            self._erp_invoice_line_items.append(obj)

    def remove_erp_invoice_line_items(self, *erp_invoice_line_items):
        for obj in erp_invoice_line_items:
            if self in obj._customer_billing_infos:
                obj._customer_billing_infos.remove(self)
            self._erp_invoice_line_items.remove(obj)
    # >>> erp_invoice_line_items

    # <<< customer_account
    # @generated
    def get_customer_account(self):
        """ 
        """
        return self._customer_account

    def set_customer_account(self, value):
        if self._customer_account is not None:
            filtered = [x for x in self.customer_account.customer_billing_infos if x != self]
            self._customer_account._customer_billing_infos = filtered

        self._customer_account = value
        if self._customer_account is not None:
            self._customer_account._customer_billing_infos.append(self)

    customer_account = property(get_customer_account, set_customer_account)
    # >>> customer_account


    def __str__(self):
        """ Returns a string representation of the CustomerBillingInfo.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< customer_billing_info.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the CustomerBillingInfo.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "CustomerBillingInfo", self.uri)
        if format:
            indent += ' ' * depth

        for obj in self.erp_invoice_line_items:
            s += '%s<%s:CustomerBillingInfo.erp_invoice_line_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.customer_account is not None:
            s += '%s<%s:CustomerBillingInfo.customer_account rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.customer_account.uri)
        s += '%s<%s:CustomerBillingInfo.kind>%s</%s:CustomerBillingInfo.kind>' % \
            (indent, ns_prefix, self.kind, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.pymt_plan_type>%s</%s:CustomerBillingInfo.pymt_plan_type>' % \
            (indent, ns_prefix, self.pymt_plan_type, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.billing_date>%s</%s:CustomerBillingInfo.billing_date>' % \
            (indent, ns_prefix, self.billing_date, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.pymt_plan_amt>%s</%s:CustomerBillingInfo.pymt_plan_amt>' % \
            (indent, ns_prefix, self.pymt_plan_amt, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.out_balance>%s</%s:CustomerBillingInfo.out_balance>' % \
            (indent, ns_prefix, self.out_balance, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.last_payment_amt>%s</%s:CustomerBillingInfo.last_payment_amt>' % \
            (indent, ns_prefix, self.last_payment_amt, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.last_payment_date>%s</%s:CustomerBillingInfo.last_payment_date>' % \
            (indent, ns_prefix, self.last_payment_date, ns_prefix)
        s += '%s<%s:CustomerBillingInfo.due_date>%s</%s:CustomerBillingInfo.due_date>' % \
            (indent, ns_prefix, self.due_date, ns_prefix)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "CustomerBillingInfo")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> customer_billing_info.serialize


class OutageHistory(Document):
    """ A document collecting OutageReports, that allows utilities to examine the number of outages suffered by a customer. Also provides data to calculate the total supply interruption to any customer over a given period.
    """
    # <<< outage_history
    # @generated
    def __init__(self, outage_reports=None, **kw_args):
        """ Initialises a new 'OutageHistory' instance.
        """

        self._outage_reports = []
        if outage_reports is not None:
            self.outage_reports = outage_reports
        else:
            self.outage_reports = []


        super(OutageHistory, self).__init__(**kw_args)
    # >>> outage_history

    # <<< outage_reports
    # @generated
    def get_outage_reports(self):
        """ OutageReports per customer for which this OutageHistory is created.
        """
        return self._outage_reports

    def set_outage_reports(self, value):
        for x in self._outage_reports:
            x._outage_history = None
        for y in value:
            y._outage_history = self
        self._outage_reports = value

    outage_reports = property(get_outage_reports, set_outage_reports)

    def add_outage_reports(self, *outage_reports):
        for obj in outage_reports:
            obj._outage_history = self
            self._outage_reports.append(obj)

    def remove_outage_reports(self, *outage_reports):
        for obj in outage_reports:
            obj._outage_history = None
            self._outage_reports.remove(obj)
    # >>> outage_reports


    def __str__(self):
        """ Returns a string representation of the OutageHistory.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< outage_history.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the OutageHistory.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "OutageHistory", self.uri)
        if format:
            indent += ' ' * depth

        for obj in self.outage_reports:
            s += '%s<%s:OutageHistory.outage_reports rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "OutageHistory")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> outage_history.serialize


class WorkBillingInfo(Document):
    """ Billing information for work performed for the customer. The history of Work Billing Info, Invoices, and Payments is to be maintained in associated ActivityRecords.
    """
    # <<< work_billing_info
    # @generated
    def __init__(self, due_date_time='', received_date_time='', deposit=0.0, work_price=0.0, discount=0.0, cost_estimate=0.0, issue_date_time='', erp_line_items=None, customer_account=None, works=None, **kw_args):
        """ Initialises a new 'WorkBillingInfo' instance.
        """
        # Date and time by which payment for bill is expected from client. 
        self.due_date_time = due_date_time

        # Date payment was received from client. 
        self.received_date_time = received_date_time

        # Amount of price on deposit. 
        self.deposit = deposit

        # Amount of bill. 
        self.work_price = work_price

        # Discount from standard price. 
        self.discount = discount

        # Estimated cost for work. 
        self.cost_estimate = cost_estimate

        # Date and time bill was issued to client. 
        self.issue_date_time = issue_date_time


        self._erp_line_items = []
        if erp_line_items is not None:
            self.erp_line_items = erp_line_items
        else:
            self.erp_line_items = []

        self._customer_account = None
        self.customer_account = customer_account

        self._works = []
        if works is not None:
            self.works = works
        else:
            self.works = []


        super(WorkBillingInfo, self).__init__(**kw_args)
    # >>> work_billing_info

    # <<< erp_line_items
    # @generated
    def get_erp_line_items(self):
        """ 
        """
        return self._erp_line_items

    def set_erp_line_items(self, value):
        for p in self._erp_line_items:
            filtered = [q for q in p.work_billing_infos if q != self]
            self._erp_line_items._work_billing_infos = filtered
        for r in value:
            if self not in r._work_billing_infos:
                r._work_billing_infos.append(self)
        self._erp_line_items = value

    erp_line_items = property(get_erp_line_items, set_erp_line_items)

    def add_erp_line_items(self, *erp_line_items):
        for obj in erp_line_items:
            if self not in obj._work_billing_infos:
                obj._work_billing_infos.append(self)
            self._erp_line_items.append(obj)

    def remove_erp_line_items(self, *erp_line_items):
        for obj in erp_line_items:
            if self in obj._work_billing_infos:
                obj._work_billing_infos.remove(self)
            self._erp_line_items.remove(obj)
    # >>> erp_line_items

    # <<< customer_account
    # @generated
    def get_customer_account(self):
        """ 
        """
        return self._customer_account

    def set_customer_account(self, value):
        if self._customer_account is not None:
            filtered = [x for x in self.customer_account.work_billing_infos if x != self]
            self._customer_account._work_billing_infos = filtered

        self._customer_account = value
        if self._customer_account is not None:
            self._customer_account._work_billing_infos.append(self)

    customer_account = property(get_customer_account, set_customer_account)
    # >>> customer_account

    # <<< works
    # @generated
    def get_works(self):
        """ 
        """
        return self._works

    def set_works(self, value):
        for x in self._works:
            x._work_billing_info = None
        for y in value:
            y._work_billing_info = self
        self._works = value

    works = property(get_works, set_works)

    def add_works(self, *works):
        for obj in works:
            obj._work_billing_info = self
            self._works.append(obj)

    def remove_works(self, *works):
        for obj in works:
            obj._work_billing_info = None
            self._works.remove(obj)
    # >>> works


    def __str__(self):
        """ Returns a string representation of the WorkBillingInfo.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< work_billing_info.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the WorkBillingInfo.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "WorkBillingInfo", self.uri)
        if format:
            indent += ' ' * depth

        for obj in self.erp_line_items:
            s += '%s<%s:WorkBillingInfo.erp_line_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.customer_account is not None:
            s += '%s<%s:WorkBillingInfo.customer_account rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.customer_account.uri)
        for obj in self.works:
            s += '%s<%s:WorkBillingInfo.works rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:WorkBillingInfo.due_date_time>%s</%s:WorkBillingInfo.due_date_time>' % \
            (indent, ns_prefix, self.due_date_time, ns_prefix)
        s += '%s<%s:WorkBillingInfo.received_date_time>%s</%s:WorkBillingInfo.received_date_time>' % \
            (indent, ns_prefix, self.received_date_time, ns_prefix)
        s += '%s<%s:WorkBillingInfo.deposit>%s</%s:WorkBillingInfo.deposit>' % \
            (indent, ns_prefix, self.deposit, ns_prefix)
        s += '%s<%s:WorkBillingInfo.work_price>%s</%s:WorkBillingInfo.work_price>' % \
            (indent, ns_prefix, self.work_price, ns_prefix)
        s += '%s<%s:WorkBillingInfo.discount>%s</%s:WorkBillingInfo.discount>' % \
            (indent, ns_prefix, self.discount, ns_prefix)
        s += '%s<%s:WorkBillingInfo.cost_estimate>%s</%s:WorkBillingInfo.cost_estimate>' % \
            (indent, ns_prefix, self.cost_estimate, ns_prefix)
        s += '%s<%s:WorkBillingInfo.issue_date_time>%s</%s:WorkBillingInfo.issue_date_time>' % \
            (indent, ns_prefix, self.issue_date_time, ns_prefix)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "WorkBillingInfo")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> work_billing_info.serialize


class PowerQualityPricing(Document):
    """ Pricing can be based on power quality.
    """
    # <<< power_quality_pricing
    # @generated
    def __init__(self, emergency_low_volt_limit=0.0, emergency_high_volt_limit=0.0, volt_limit_viol_cost=0.0, value_uninterrupted_service_p=0.0, normal_low_volt_limit=0.0, volt_imbalance_viol_cost=0.0, normal_high_volt_limit=0.0, power_factor_min=0.0, value_uninterrupted_service_energy=0.0, pricing_structure=None, service_delivery_points=None, **kw_args):
        """ Initialises a new 'PowerQualityPricing' instance.
        """
        # Emergency low voltage limit. 
        self.emergency_low_volt_limit = emergency_low_volt_limit

        # Emergency high voltage limit. 
        self.emergency_high_volt_limit = emergency_high_volt_limit

        # Voltage limit violation cost (Cost per unit Voltage). 
        self.volt_limit_viol_cost = volt_limit_viol_cost

        # Value of uninterrupted service (Cost per active power). 
        self.value_uninterrupted_service_p = value_uninterrupted_service_p

        # Normal low voltage limit. 
        self.normal_low_volt_limit = normal_low_volt_limit

        # Voltage imbalance violation cost (Cost per unit Voltage). 
        self.volt_imbalance_viol_cost = volt_imbalance_viol_cost

        # Normal high voltage limit. 
        self.normal_high_volt_limit = normal_high_volt_limit

        # Threshold minimum power factor for this PricingStructure, specified in instances where a special charge is levied if the actual power factor for a Service falls below the value specified here. 
        self.power_factor_min = power_factor_min

        # Value of uninterrupted service (Cost per energy). 
        self.value_uninterrupted_service_energy = value_uninterrupted_service_energy


        self._pricing_structure = None
        self.pricing_structure = pricing_structure

        self._service_delivery_points = []
        if service_delivery_points is not None:
            self.service_delivery_points = service_delivery_points
        else:
            self.service_delivery_points = []


        super(PowerQualityPricing, self).__init__(**kw_args)
    # >>> power_quality_pricing

    # <<< pricing_structure
    # @generated
    def get_pricing_structure(self):
        """ 
        """
        return self._pricing_structure

    def set_pricing_structure(self, value):
        if self._pricing_structure is not None:
            filtered = [x for x in self.pricing_structure.power_quality_pricings if x != self]
            self._pricing_structure._power_quality_pricings = filtered

        self._pricing_structure = value
        if self._pricing_structure is not None:
            self._pricing_structure._power_quality_pricings.append(self)

    pricing_structure = property(get_pricing_structure, set_pricing_structure)
    # >>> pricing_structure

    # <<< service_delivery_points
    # @generated
    def get_service_delivery_points(self):
        """ 
        """
        return self._service_delivery_points

    def set_service_delivery_points(self, value):
        for p in self._service_delivery_points:
            filtered = [q for q in p.power_quality_pricings if q != self]
            self._service_delivery_points._power_quality_pricings = filtered
        for r in value:
            if self not in r._power_quality_pricings:
                r._power_quality_pricings.append(self)
        self._service_delivery_points = value

    service_delivery_points = property(get_service_delivery_points, set_service_delivery_points)

    def add_service_delivery_points(self, *service_delivery_points):
        for obj in service_delivery_points:
            if self not in obj._power_quality_pricings:
                obj._power_quality_pricings.append(self)
            self._service_delivery_points.append(obj)

    def remove_service_delivery_points(self, *service_delivery_points):
        for obj in service_delivery_points:
            if self in obj._power_quality_pricings:
                obj._power_quality_pricings.remove(self)
            self._service_delivery_points.remove(obj)
    # >>> service_delivery_points


    def __str__(self):
        """ Returns a string representation of the PowerQualityPricing.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< power_quality_pricing.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the PowerQualityPricing.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "PowerQualityPricing", self.uri)
        if format:
            indent += ' ' * depth

        if self.pricing_structure is not None:
            s += '%s<%s:PowerQualityPricing.pricing_structure rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.pricing_structure.uri)
        for obj in self.service_delivery_points:
            s += '%s<%s:PowerQualityPricing.service_delivery_points rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:PowerQualityPricing.emergency_low_volt_limit>%s</%s:PowerQualityPricing.emergency_low_volt_limit>' % \
            (indent, ns_prefix, self.emergency_low_volt_limit, ns_prefix)
        s += '%s<%s:PowerQualityPricing.emergency_high_volt_limit>%s</%s:PowerQualityPricing.emergency_high_volt_limit>' % \
            (indent, ns_prefix, self.emergency_high_volt_limit, ns_prefix)
        s += '%s<%s:PowerQualityPricing.volt_limit_viol_cost>%s</%s:PowerQualityPricing.volt_limit_viol_cost>' % \
            (indent, ns_prefix, self.volt_limit_viol_cost, ns_prefix)
        s += '%s<%s:PowerQualityPricing.value_uninterrupted_service_p>%s</%s:PowerQualityPricing.value_uninterrupted_service_p>' % \
            (indent, ns_prefix, self.value_uninterrupted_service_p, ns_prefix)
        s += '%s<%s:PowerQualityPricing.normal_low_volt_limit>%s</%s:PowerQualityPricing.normal_low_volt_limit>' % \
            (indent, ns_prefix, self.normal_low_volt_limit, ns_prefix)
        s += '%s<%s:PowerQualityPricing.volt_imbalance_viol_cost>%s</%s:PowerQualityPricing.volt_imbalance_viol_cost>' % \
            (indent, ns_prefix, self.volt_imbalance_viol_cost, ns_prefix)
        s += '%s<%s:PowerQualityPricing.normal_high_volt_limit>%s</%s:PowerQualityPricing.normal_high_volt_limit>' % \
            (indent, ns_prefix, self.normal_high_volt_limit, ns_prefix)
        s += '%s<%s:PowerQualityPricing.power_factor_min>%s</%s:PowerQualityPricing.power_factor_min>' % \
            (indent, ns_prefix, self.power_factor_min, ns_prefix)
        s += '%s<%s:PowerQualityPricing.value_uninterrupted_service_energy>%s</%s:PowerQualityPricing.value_uninterrupted_service_energy>' % \
            (indent, ns_prefix, self.value_uninterrupted_service_energy, ns_prefix)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "PowerQualityPricing")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> power_quality_pricing.serialize


class ServiceGuarantee(Document):
    """ A service guarantee, often imposed by a regulator, defines conditions that, if not satisfied, will result in the utility making a monetary payment to the customer. Note that guarantee's identifier is in the 'name' attribute and the status of the guarantee is in the 'Status.status' attribute. Example service requirements include: 1) If power is not restored within 24 hours, customers can claim $50 for residential customers or $100 for commercial and industrial customers. In addition for each extra period of 12 hours the customer's supply has not been activated, the customer can claim $25. 2) If a customer has a question about their electricity bill, the utility will investigate and respond to the inquiry within 15 working days. If utility fails to meet its guarantee, utility will automatically pay the customer $50.
    """
    # <<< service_guarantee
    # @generated
    def __init__(self, automatic_pay=False, service_requirement='', pay_amount=0.0, application_period=None, **kw_args):
        """ Initialises a new 'ServiceGuarantee' instance.
        """
        # True if utility must autmatically pay the specified amount whenever the condition is not satisified, otherwise customer must make a claim to receive payment. 
        self.automatic_pay = automatic_pay

        # Explanation of the requirement and conditions for satisfying it. 
        self.service_requirement = service_requirement

        # Amount to be paid by the service provider to the customer for each violation of the 'serviceRequirement'. 
        self.pay_amount = pay_amount


        self.application_period = application_period


        super(ServiceGuarantee, self).__init__(**kw_args)
    # >>> service_guarantee

    # <<< application_period
    # @generated
    # Period in which this service guantee applies.
    application_period = None
    # >>> application_period


    def __str__(self):
        """ Returns a string representation of the ServiceGuarantee.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< service_guarantee.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the ServiceGuarantee.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "ServiceGuarantee", self.uri)
        if format:
            indent += ' ' * depth

        if self.application_period is not None:
            s += '%s<%s:ServiceGuarantee.application_period rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.application_period.uri)
        s += '%s<%s:ServiceGuarantee.automatic_pay>%s</%s:ServiceGuarantee.automatic_pay>' % \
            (indent, ns_prefix, self.automatic_pay, ns_prefix)
        s += '%s<%s:ServiceGuarantee.service_requirement>%s</%s:ServiceGuarantee.service_requirement>' % \
            (indent, ns_prefix, self.service_requirement, ns_prefix)
        s += '%s<%s:ServiceGuarantee.pay_amount>%s</%s:ServiceGuarantee.pay_amount>' % \
            (indent, ns_prefix, self.pay_amount, ns_prefix)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.activity_records:
            s += '%s<%s:Document.activity_records rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_organisation_roles:
            s += '%s<%s:Document.erp_organisation_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.scheduled_events:
            s += '%s<%s:Document.scheduled_events rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.from_document_roles:
            s += '%s<%s:Document.from_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.location_roles:
            s += '%s<%s:Document.location_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.power_system_resource_roles:
            s += '%s<%s:Document.power_system_resource_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.network_data_sets:
            s += '%s<%s:Document.network_data_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.erp_person_roles:
            s += '%s<%s:Document.erp_person_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_items:
            s += '%s<%s:Document.change_items rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.measurements:
            s += '%s<%s:Document.measurements rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.doc_status is not None:
            s += '%s<%s:Document.doc_status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.doc_status.uri)
        for obj in self.schedule_parameter_infos:
            s += '%s<%s:Document.schedule_parameter_infos rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.electronic_address is not None:
            s += '%s<%s:Document.electronic_address rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.electronic_address.uri)
        for obj in self.to_document_roles:
            s += '%s<%s:Document.to_document_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        if self.status is not None:
            s += '%s<%s:Document.status rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.status.uri)
        for obj in self.asset_roles:
            s += '%s<%s:Document.asset_roles rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        for obj in self.change_sets:
            s += '%s<%s:Document.change_sets rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Document.subject>%s</%s:Document.subject>' % \
            (indent, ns_prefix, self.subject, ns_prefix)
        s += '%s<%s:Document.revision_number>%s</%s:Document.revision_number>' % \
            (indent, ns_prefix, self.revision_number, ns_prefix)
        s += '%s<%s:Document.category>%s</%s:Document.category>' % \
            (indent, ns_prefix, self.category, ns_prefix)
        s += '%s<%s:Document.last_modified_date_time>%s</%s:Document.last_modified_date_time>' % \
            (indent, ns_prefix, self.last_modified_date_time, ns_prefix)
        s += '%s<%s:Document.title>%s</%s:Document.title>' % \
            (indent, ns_prefix, self.title, ns_prefix)
        s += '%s<%s:Document.created_date_time>%s</%s:Document.created_date_time>' % \
            (indent, ns_prefix, self.created_date_time, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "ServiceGuarantee")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> service_guarantee.serialize


class SubscribePowerCurve(Curve):
    """ Price curve for specifying the cost of energy (X) at points in time (y1) according to a prcing structure, which is based on a tariff.
    """
    # <<< subscribe_power_curve
    # @generated
    def __init__(self, pricing_structure=None, **kw_args):
        """ Initialises a new 'SubscribePowerCurve' instance.
        """

        self._pricing_structure = None
        self.pricing_structure = pricing_structure


        super(SubscribePowerCurve, self).__init__(**kw_args)
    # >>> subscribe_power_curve

    # <<< pricing_structure
    # @generated
    def get_pricing_structure(self):
        """ 
        """
        return self._pricing_structure

    def set_pricing_structure(self, value):
        if self._pricing_structure is not None:
            self._pricing_structure._subscribe_power_curve = None

        self._pricing_structure = value
        if self._pricing_structure is not None:
            self._pricing_structure._subscribe_power_curve = self

    pricing_structure = property(get_pricing_structure, set_pricing_structure)
    # >>> pricing_structure


    def __str__(self):
        """ Returns a string representation of the SubscribePowerCurve.
        """
        return self.serialize(header=True, depth=2, format=True)


    # <<< subscribe_power_curve.serialize
    # @generated
    def serialize(self, header=False, depth=0, format=False):
        """ Returns an RDF/XML representation of the SubscribePowerCurve.
        """
        s = ''
        indent = ' ' * depth if depth else ''
        if format:
            indent = '\n' + indent
        if header:
            s += '<?xml version="1.0" encoding="UTF-8"?>\n'
            s += '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:%s="%s">' % \
                (ns_prefix, ns_uri)
            if format:
                indent += ' ' * depth

        s += '%s<%s:%s rdf:ID="%s">' % (indent, ns_prefix, "SubscribePowerCurve", self.uri)
        if format:
            indent += ' ' * depth

        if self.pricing_structure is not None:
            s += '%s<%s:SubscribePowerCurve.pricing_structure rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.pricing_structure.uri)
        if self.parent is not None:
            s += '%s<%s:Element.parent rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.parent.uri)
        s += '%s<%s:Element.uuid>%s</%s:Element.uuid>' % \
            (indent, ns_prefix, self.uuid, ns_prefix)
        if self.modeling_authority_set is not None:
            s += '%s<%s:IdentifiedObject.modeling_authority_set rdf:resource="#%s"/>' % \
                (indent, ns_prefix, self.modeling_authority_set.uri)
        s += '%s<%s:IdentifiedObject.description>%s</%s:IdentifiedObject.description>' % \
            (indent, ns_prefix, self.description, ns_prefix)
        s += '%s<%s:IdentifiedObject.m_rid>%s</%s:IdentifiedObject.m_rid>' % \
            (indent, ns_prefix, self.m_rid, ns_prefix)
        s += '%s<%s:IdentifiedObject.name>%s</%s:IdentifiedObject.name>' % \
            (indent, ns_prefix, self.name, ns_prefix)
        s += '%s<%s:IdentifiedObject.path_name>%s</%s:IdentifiedObject.path_name>' % \
            (indent, ns_prefix, self.path_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.local_name>%s</%s:IdentifiedObject.local_name>' % \
            (indent, ns_prefix, self.local_name, ns_prefix)
        s += '%s<%s:IdentifiedObject.alias_name>%s</%s:IdentifiedObject.alias_name>' % \
            (indent, ns_prefix, self.alias_name, ns_prefix)
        for obj in self.curve_datas:
            s += '%s<%s:Curve.curve_datas rdf:resource="#%s"/>' % \
                (indent, ns_prefix, obj.uri)
        s += '%s<%s:Curve.y3_multiplier>%s</%s:Curve.y3_multiplier>' % \
            (indent, ns_prefix, self.y3_multiplier, ns_prefix)
        s += '%s<%s:Curve.y2_multiplier>%s</%s:Curve.y2_multiplier>' % \
            (indent, ns_prefix, self.y2_multiplier, ns_prefix)
        s += '%s<%s:Curve.x_multiplier>%s</%s:Curve.x_multiplier>' % \
            (indent, ns_prefix, self.x_multiplier, ns_prefix)
        s += '%s<%s:Curve.y2_unit>%s</%s:Curve.y2_unit>' % \
            (indent, ns_prefix, self.y2_unit, ns_prefix)
        s += '%s<%s:Curve.curve_style>%s</%s:Curve.curve_style>' % \
            (indent, ns_prefix, self.curve_style, ns_prefix)
        s += '%s<%s:Curve.y1_unit>%s</%s:Curve.y1_unit>' % \
            (indent, ns_prefix, self.y1_unit, ns_prefix)
        s += '%s<%s:Curve.y1_multiplier>%s</%s:Curve.y1_multiplier>' % \
            (indent, ns_prefix, self.y1_multiplier, ns_prefix)
        s += '%s<%s:Curve.y3_unit>%s</%s:Curve.y3_unit>' % \
            (indent, ns_prefix, self.y3_unit, ns_prefix)
        s += '%s<%s:Curve.x_unit>%s</%s:Curve.x_unit>' % \
            (indent, ns_prefix, self.x_unit, ns_prefix)

        if format:
            indent = indent[:-depth]
        s += '%s</%s:%s>' % (indent, ns_prefix, "SubscribePowerCurve")

        if header:
            s += '%s</rdf:RDF>' % indent[:-depth]

        return s
    # >>> subscribe_power_curve.serialize


# <<< inf_customers
# @generated
# >>> inf_customers
